.. _header-n246:

DeribitSimpleBot
================

| Реализация простого бота для криптобиржи Deribit.\\
| Реализация для websockets JSON-RPC v.2
  (`Документация <https://docs.deribit.com/>`__)

.. _header-n249:

Возможности
-----------

1. Возможность работы с несколькими инструментами одновременно

2. Возобновление работы после остановки

3. Возможность использвоать разные системы хранения ордеров

.. _header-n257:

Алгоримт работы
---------------

1. Робот выставляет ордер #1 на покупку по цене **buy price = current
   price - gap / 2**.

2. | **(a)** Если цена уменьшается до **buy price**, то ордер #1, скорее
     всего, будет исполнен. В этом случае перейти к пункту 3.\\
   | **(b)** Если цена увеличивается до такого значения, что становится
     истинным условие **current price > buy price + gap + gap ignore**,
     то робот должен отменить ордер #1. Далее, вернуться к пункту 1.

3. Робот выставляет ордер #2 на продажу по цене **sell price = current
   price + gap**.

4. | **(a)** Если цена увеличивается до sell price, то ордер #2, скорее
     всего, будет исполнен. В этом случае вернуться к пункту 1.\\
   | **(b)** Если цена уменьшается до такого значения, что становится
     истинным условие **current price < sell price - gap - gap ignore**,
     то робот должен отменить ордер #2. После этого следует вернуться к
     пункту 3.

.. _header-n267:

Рабочий пример
--------------

`Пример
приложение <https://github.com/n-eliseev/deribitsimplebot/tree/master/example-app>`__
(`описание к нему <https://github.com/n-eliseev/deribitsimplebot/>`__)
